if [ ! -e /etc/qemu-integration.conf ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/qemu-integration.conf /etc/qemu-integration.conf
fi

